@@ -126,6 +126,8 @@ Change log
 ----------
 
 * 0.3:
+    * 0.3.3 (*2013-03-17*):
+        Worked around pip bug.
     * 0.3.2 (*2013-03-17*):
         Fixed new setup bug (setup.py)
     * 0.3.1 (*2013-03-17*):
@@ -146,4 +148,4 @@ Change log
         First version.
 """
 
-__version__ = "0.3.2"
\ No newline at end of file
+__version__ = "0.3.3"
\ No newline at end of file
